@@ -29,6 +29,7 @@
 
 #include <QGroupBox>
 #include <LXQt/Settings>
+#include <LXQt/lxqtbacklight.h>
 
 #include "powermanagementsettings.h"
 
@@ -41,20 +42,27 @@ class IdlenessWatcherSettings : public QWidget
     Q_OBJECT
 
 public:
-    explicit IdlenessWatcherSettings(QWidget *parent = 0);
-    ~IdlenessWatcherSettings();
+    explicit IdlenessWatcherSettings(QWidget *parent = nullptr);
+    ~IdlenessWatcherSettings() override;
 
-public slots:
+public Q_SLOTS:
     void loadSettings();
 
-private slots:
+private Q_SLOTS:
     void minutesChanged(int newVal);
     void secondsChanged(int newVal);
     void saveSettings();
+    void backlightCheckButtonPressed();
+    void backlightCheckButtonReleased();
 
 private:
     PowerManagementSettings mSettings;
     Ui::IdlenessWatcherSettings *mUi;
+    LXQt::Backlight *mBacklight;
+    int mBacklightActualValue;
+    
+    void mConnectSignals();
+    void mDisconnectSignals();
 };
 
 #endif // IDLE_SETTINGS_H
