@@ -51,6 +51,9 @@ namespace PowerManagementSettingsConstants
     const QString IDLENESS_BACKLIGHT_TIME { QL1S("idlenessTime") };
     const QString IDLENESS_BACKLIGHT { QL1S("backlightIdleness") };
     const QString IDLENESS_BACKLIGHT_ON_BATTERY_DISCHARGING { QL1S("backlightIdlenessOnBatteryDischarging") };
+    const QString POWER_KEY_ACTION { QL1S("powerKeyAction") };
+    const QString SUSPEND_KEY_ACTION { QL1S("suspendKeyAction") };
+    const QString HIBERNATE_KEY_ACTION { QL1S("hibernateKeyAction") };
 }
 
 using namespace PowerManagementSettingsConstants;
@@ -266,3 +269,33 @@ void PowerManagementSettings::setIdlenessBacklightOnBatteryDischargingEnabled(bo
 {
     setValue(IDLENESS_BACKLIGHT_ON_BATTERY_DISCHARGING, enabled);
 }
+
+int PowerManagementSettings::getPowerKeyAction()
+{
+    return value(POWER_KEY_ACTION, LXQt::Power::Action::PowerShutdown).toInt();
+}
+
+void PowerManagementSettings::setPowerKeyAction(int action)
+{
+    setValue(POWER_KEY_ACTION, action);
+}
+
+int PowerManagementSettings::getSuspendKeyAction()
+{
+    return value(SUSPEND_KEY_ACTION, LXQt::Power::Action::PowerSuspend).toInt();
+}
+
+void PowerManagementSettings::setSuspendKeyAction(int action)
+{
+    setValue(SUSPEND_KEY_ACTION, action);
+}
+
+int PowerManagementSettings::getHibernateKeyAction()
+{
+    return value(HIBERNATE_KEY_ACTION, LXQt::Power::Action::PowerHibernate).toInt();
+}
+
+void PowerManagementSettings::setHibernateKeyAction(int action)
+{
+    setValue(HIBERNATE_KEY_ACTION, action);
+}
\ No newline at end of file
