@@ -90,18 +90,27 @@ public:
 
     bool isIdlenessWatcherEnabled();
     void setIdlenessWatcherEnabled(bool idlenessWatcherEnabled);
-    
+
     bool isIdlenessBacklightWatcherEnabled();
     void setIdlenessBacklightWatcherEnabled(bool idlenessBacklightWatcherEnabled);
-    
+
     QTime getIdlenessBacklightTime();
     void setIdlenessBacklightTime(QTime idlenessBacklightTime);
-    
+
     int getBacklight();
     void setBacklight(int backlight);
-    
+
     bool isIdlenessBacklightOnBatteryDischargingEnabled();
     void setIdlenessBacklightOnBatteryDischargingEnabled(bool enabled);
+
+    int getPowerKeyAction();
+    void setPowerKeyAction(int action);
+    
+    int getSuspendKeyAction();
+    void setSuspendKeyAction(int action);
+    
+    int getHibernateKeyAction();
+    void setHibernateKeyAction(int action);
 };
 
 
