@@ -80,28 +80,59 @@
     <message>
         <location filename="../idlenesswatchersettings.ui" line="17"/>
         <source>Enab&amp;le Idleness Watcher</source>
-        <translation>&amp;Aktiviere Leerlaufüberwachung</translation>
+        <translation>&amp;Leerlaufüberwachung aktivieren</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="38"/>
+        <location filename="../idlenesswatchersettings.ui" line="34"/>
         <source>When idle then:</source>
         <translation>Bei Leerlauf:</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="57"/>
+        <location filename="../idlenesswatchersettings.ui" line="53"/>
+        <location filename="../idlenesswatchersettings.ui" line="123"/>
         <source>Idle time:</source>
         <translation>Leerlaufzeit:</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="70"/>
+        <location filename="../idlenesswatchersettings.ui" line="66"/>
         <source> minutes</source>
         <translation> Minuten</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="83"/>
+        <location filename="../idlenesswatchersettings.ui" line="79"/>
         <source> seconds</source>
         <translation> Sekunden</translation>
     </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="94"/>
+        <source>Enable Backlight Change</source>
+        <translation>Änderung der Hintergrundbeleuchtung aktivieren</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="103"/>
+        <source>Backlight (%):</source>
+        <translation>Hintergrundbeleuchtung (%):</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="130"/>
+        <source>Minutes:Seconds</source>
+        <translation>Minuten:Sekunden</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="150"/>
+        <source>mm:ss</source>
+        <translation>mm:ss</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="157"/>
+        <source>Check backlight</source>
+        <translation>Hintergrundbeleuchtung prüfen</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="164"/>
+        <source>On battery discharging </source>
+        <translation>Beim Entladen der Batterie </translation>
+    </message>
 </context>
 <context>
     <name>LidWatcherSettings</name>
@@ -129,7 +160,7 @@
     <message>
         <location filename="../lidwatchersettings.ui" line="63"/>
         <source>Suspend</source>
-        <translation>Bereitschaft</translation>
+        <translation>Bereitschaftszustand</translation>
     </message>
     <message>
         <location filename="../lidwatchersettings.ui" line="68"/>
@@ -156,25 +187,58 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="36"/>
+        <location filename="../mainwindow.cpp" line="37"/>
         <source>Power Management Settings</source>
         <translation>Einstellungen der Energieverwaltung</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="39"/>
+        <location filename="../mainwindow.cpp" line="40"/>
         <source>Battery</source>
         <translation>Batterie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="43"/>
+        <location filename="../mainwindow.cpp" line="44"/>
         <source>Lid</source>
         <translation>Deckel</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="48"/>
         <source>Idle</source>
         <translation>Leerlauf</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="52"/>
+        <source>Power keys</source>
+        <translation>Ein/Aus-Tasten</translation>
+    </message>
+</context>
+<context>
+    <name>PowerKeysSettings</name>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="14"/>
+        <source>Form</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="20"/>
+        <source>Handle Power Keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="26"/>
+        <source>Power Key Action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="42"/>
+        <source>Suspend Key Action</source>
+        <translation>Bereitschaftszustand-Tastenaktion</translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="49"/>
+        <source>Hibernate Key Action</source>
+        <translation>Ruhezustand-Tastenaktion</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -185,26 +249,31 @@
     </message>
     <message>
         <location filename="../helpers.cpp" line="36"/>
+        <source>Ask</source>
+        <translation>Nachfragen</translation>
+    </message>
+    <message>
+        <location filename="../helpers.cpp" line="37"/>
         <source>Lock screen</source>
         <translation>Sperre Bildschirm</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="37"/>
+        <location filename="../helpers.cpp" line="38"/>
         <source>Suspend</source>
         <translation>Bereitschaft</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="38"/>
+        <location filename="../helpers.cpp" line="39"/>
         <source>Hibernate</source>
         <translation>Ruhezustand</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="39"/>
+        <location filename="../helpers.cpp" line="40"/>
         <source>Shutdown</source>
         <translation>Herunterfahren</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="40"/>
+        <location filename="../helpers.cpp" line="41"/>
         <source>Turn Off monitor(s)</source>
         <translation>Bildschirm(e) ausschalten</translation>
     </message>
