@@ -83,25 +83,56 @@
         <translation>Configurer le comportement en cas d&apos;&amp;inactivité</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="38"/>
+        <location filename="../idlenesswatchersettings.ui" line="34"/>
         <source>When idle then:</source>
         <translation>En cas d&apos;inactivité :</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="57"/>
+        <location filename="../idlenesswatchersettings.ui" line="53"/>
+        <location filename="../idlenesswatchersettings.ui" line="123"/>
         <source>Idle time:</source>
         <translation>Temps d&apos;inactivité :</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="70"/>
+        <location filename="../idlenesswatchersettings.ui" line="66"/>
         <source> minutes</source>
         <translation> minutes</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="83"/>
+        <location filename="../idlenesswatchersettings.ui" line="79"/>
         <source> seconds</source>
         <translation> secondes</translation>
     </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="94"/>
+        <source>Enable Backlight Change</source>
+        <translation>Activer le changement de rétroéclairage</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="103"/>
+        <source>Backlight (%):</source>
+        <translation>Rétroéclairage (%) :</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="130"/>
+        <source>Minutes:Seconds</source>
+        <translation>Minutes:Secondes</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="150"/>
+        <source>mm:ss</source>
+        <translation>mm:ss</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="157"/>
+        <source>Check backlight</source>
+        <translation>Vérifier le rétroéclairage</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="164"/>
+        <source>On battery discharging </source>
+        <translation>Lorsque la batterie se décharge </translation>
+    </message>
 </context>
 <context>
     <name>LidWatcherSettings</name>
@@ -156,25 +187,58 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="36"/>
+        <location filename="../mainwindow.cpp" line="37"/>
         <source>Power Management Settings</source>
         <translation>Paramètres de gestion de l&apos;alimentation</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="39"/>
+        <location filename="../mainwindow.cpp" line="40"/>
         <source>Battery</source>
         <translation>Batterie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="43"/>
+        <location filename="../mainwindow.cpp" line="44"/>
         <source>Lid</source>
         <translation>Capot</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="48"/>
         <source>Idle</source>
         <translation>Inactivité</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="52"/>
+        <source>Power keys</source>
+        <translation>Boutons d&apos;alimentation</translation>
+    </message>
+</context>
+<context>
+    <name>PowerKeysSettings</name>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="14"/>
+        <source>Form</source>
+        <translation>Forme</translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="20"/>
+        <source>Handle Power Keys</source>
+        <translation>Gérer les touches d&apos;alimentation</translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="26"/>
+        <source>Power Key Action</source>
+        <translation>Action des touches d&apos;alimentation</translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="42"/>
+        <source>Suspend Key Action</source>
+        <translation>Suspendre l&apos;action de la touche</translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="49"/>
+        <source>Hibernate Key Action</source>
+        <translation>Action de la touche Hiberner</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -185,26 +249,31 @@
     </message>
     <message>
         <location filename="../helpers.cpp" line="36"/>
+        <source>Ask</source>
+        <translation type="unfinished">Demander</translation>
+    </message>
+    <message>
+        <location filename="../helpers.cpp" line="37"/>
         <source>Lock screen</source>
         <translation>Verrouiller l&apos;écran</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="37"/>
+        <location filename="../helpers.cpp" line="38"/>
         <source>Suspend</source>
         <translation>Suspendre</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="38"/>
+        <location filename="../helpers.cpp" line="39"/>
         <source>Hibernate</source>
         <translation>Hiberner</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="39"/>
+        <location filename="../helpers.cpp" line="40"/>
         <source>Shutdown</source>
         <translation>Arrêter</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="40"/>
+        <location filename="../helpers.cpp" line="41"/>
         <source>Turn Off monitor(s)</source>
         <translation>Éteindre le(s) moniteur(s)</translation>
     </message>
