@@ -83,25 +83,56 @@
         <translation>Aktifkan Pemantau Siaga</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="38"/>
+        <location filename="../idlenesswatchersettings.ui" line="34"/>
         <source>When idle then:</source>
         <translation>Saat siaga maka:</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="57"/>
+        <location filename="../idlenesswatchersettings.ui" line="53"/>
+        <location filename="../idlenesswatchersettings.ui" line="123"/>
         <source>Idle time:</source>
         <translation>Waktu siaga:</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="70"/>
+        <location filename="../idlenesswatchersettings.ui" line="66"/>
         <source> minutes</source>
         <translation> menit</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="83"/>
+        <location filename="../idlenesswatchersettings.ui" line="79"/>
         <source> seconds</source>
         <translation> detik</translation>
     </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="94"/>
+        <source>Enable Backlight Change</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="103"/>
+        <source>Backlight (%):</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="130"/>
+        <source>Minutes:Seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="150"/>
+        <source>mm:ss</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="157"/>
+        <source>Check backlight</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="164"/>
+        <source>On battery discharging </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LidWatcherSettings</name>
@@ -156,25 +187,58 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="36"/>
+        <location filename="../mainwindow.cpp" line="37"/>
         <source>Power Management Settings</source>
         <translation>Pengaturan Manajemen Daya</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="39"/>
+        <location filename="../mainwindow.cpp" line="40"/>
         <source>Battery</source>
         <translation>Baterai</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="43"/>
+        <location filename="../mainwindow.cpp" line="44"/>
         <source>Lid</source>
         <translation>Lid</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="48"/>
         <source>Idle</source>
         <translation>Siaga</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="52"/>
+        <source>Power keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>PowerKeysSettings</name>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="14"/>
+        <source>Form</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="20"/>
+        <source>Handle Power Keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="26"/>
+        <source>Power Key Action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="42"/>
+        <source>Suspend Key Action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerkeyssettings.ui" line="49"/>
+        <source>Hibernate Key Action</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -185,26 +249,31 @@
     </message>
     <message>
         <location filename="../helpers.cpp" line="36"/>
+        <source>Ask</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../helpers.cpp" line="37"/>
         <source>Lock screen</source>
         <translation>Kunci layar</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="37"/>
+        <location filename="../helpers.cpp" line="38"/>
         <source>Suspend</source>
         <translation>Suspensi</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="38"/>
+        <location filename="../helpers.cpp" line="39"/>
         <source>Hibernate</source>
         <translation>Hibernasi</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="39"/>
+        <location filename="../helpers.cpp" line="40"/>
         <source>Shutdown</source>
         <translation>Matikan</translation>
     </message>
     <message>
-        <location filename="../helpers.cpp" line="40"/>
+        <location filename="../helpers.cpp" line="41"/>
         <source>Turn Off monitor(s)</source>
         <translation>Matikan monitor</translation>
     </message>
