@@ -25,6 +25,7 @@
 #ifndef IDLENESSWATCHER_H
 #define IDLENESSWATCHER_H
 
+#include <LXQt/lxqtbacklight.h>
 #include "../config/powermanagementsettings.h"
 #include "watcher.h"
 
@@ -33,16 +34,23 @@ class IdlenessWatcher : public Watcher
     Q_OBJECT
 
 public:
-    explicit IdlenessWatcher(QObject* parent = 0);
-    virtual ~IdlenessWatcher();
+    explicit IdlenessWatcher(QObject* parent = nullptr);
+    ~IdlenessWatcher() override;
 
-private slots:
+private Q_SLOTS:
     void setup();
     void timeoutReached(int identifier);
+    void resumingFromIdle();
+    void onBatteryChanged(int newState, const QString &udi = QString());
     void onSettingsChanged();
 
 private:
     PowerManagementSettings mPSettings;
+    int mIdleWatcher;
+    int mIdleBacklightWatcher;
+    LXQt::Backlight *mBacklight;
+    int mBacklightActualValue;
+    bool mDischarging;
 };
 
 #endif // IDLENESSWATCHER_H
