@@ -222,22 +222,40 @@
         </translation>
     </message>
 </context>
+<context>
+    <name>PowerButton</name>
+    <message>
+        <location filename="../powerbutton.cpp" line="72"/>
+        <source>Power off key action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerbutton.cpp" line="79"/>
+        <source>Suspend key action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerbutton.cpp" line="86"/>
+        <source>Hibernate key action</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PowerManagementd</name>
     <message>
-        <location filename="../powermanagementd.cpp" line="112"/>
+        <location filename="../powermanagementd.cpp" line="115"/>
         <source>Power Management</source>
         <translation>Strømstyring</translation>
     </message>
     <message>
-        <location filename="../powermanagementd.cpp" line="113"/>
+        <location filename="../powermanagementd.cpp" line="116"/>
         <source>You are running LXQt Power Management for the first time.
 You can configure it from settings... </source>
         <translation>Du kører LXQt-strømstyring for første gang.
 Du kan konfigurere den fra indstillinger... </translation>
     </message>
     <message>
-        <location filename="../powermanagementd.cpp" line="114"/>
+        <location filename="../powermanagementd.cpp" line="117"/>
         <source>Configure...</source>
         <translation>Konfigurér...</translation>
     </message>
