@@ -222,22 +222,40 @@
         </translation>
     </message>
 </context>
+<context>
+    <name>PowerButton</name>
+    <message>
+        <location filename="../powerbutton.cpp" line="72"/>
+        <source>Power off key action</source>
+        <translation>Ausschalt-Tastenaktion</translation>
+    </message>
+    <message>
+        <location filename="../powerbutton.cpp" line="79"/>
+        <source>Suspend key action</source>
+        <translation>Bereitschaftszustand-Tastenaktion</translation>
+    </message>
+    <message>
+        <location filename="../powerbutton.cpp" line="86"/>
+        <source>Hibernate key action</source>
+        <translation>Ruhezustand-Tastenaktion</translation>
+    </message>
+</context>
 <context>
     <name>PowerManagementd</name>
     <message>
-        <location filename="../powermanagementd.cpp" line="112"/>
+        <location filename="../powermanagementd.cpp" line="115"/>
         <source>Power Management</source>
         <translation>Energieverwaltung</translation>
     </message>
     <message>
-        <location filename="../powermanagementd.cpp" line="113"/>
+        <location filename="../powermanagementd.cpp" line="116"/>
         <source>You are running LXQt Power Management for the first time.
 You can configure it from settings... </source>
         <translation>Sie führen die LXQt-Energieverwaltung erstmals aus.
 Sie können sie in den Einstellungen konfigurieren... </translation>
     </message>
     <message>
-        <location filename="../powermanagementd.cpp" line="114"/>
+        <location filename="../powermanagementd.cpp" line="117"/>
         <source>Configure...</source>
         <translation>Konfigurieren...</translation>
     </message>
