@@ -219,22 +219,40 @@
         </translation>
     </message>
 </context>
+<context>
+    <name>PowerButton</name>
+    <message>
+        <location filename="../powerbutton.cpp" line="72"/>
+        <source>Power off key action</source>
+        <translation>[電源 OFF]キーの動作</translation>
+    </message>
+    <message>
+        <location filename="../powerbutton.cpp" line="79"/>
+        <source>Suspend key action</source>
+        <translation>[サスペンド]キーの動作</translation>
+    </message>
+    <message>
+        <location filename="../powerbutton.cpp" line="86"/>
+        <source>Hibernate key action</source>
+        <translation>[ハイバネート]キーの動作</translation>
+    </message>
+</context>
 <context>
     <name>PowerManagementd</name>
     <message>
-        <location filename="../powermanagementd.cpp" line="112"/>
+        <location filename="../powermanagementd.cpp" line="115"/>
         <source>Power Management</source>
         <translation>電源管理</translation>
     </message>
     <message>
-        <location filename="../powermanagementd.cpp" line="113"/>
+        <location filename="../powermanagementd.cpp" line="116"/>
         <source>You are running LXQt Power Management for the first time.
 You can configure it from settings... </source>
         <translation>LXQt 電源管理 は初めて実行されました。
 設定を行うことができます... </translation>
     </message>
     <message>
-        <location filename="../powermanagementd.cpp" line="114"/>
+        <location filename="../powermanagementd.cpp" line="117"/>
         <source>Configure...</source>
         <translation>設定する...</translation>
     </message>
